==> zio-aws-redshift_3-5.17.201.1-sources.jar: zio/aws/redshift/model/AuthorizeSnapshotAccessRequest.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AuthorizeSnapshotAccessRequest(
    snapshotIdentifier: String,
    snapshotClusterIdentifier: Optional[String] = Optional.Absent,
    accountWithRestoreAccess: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest = {
    import AuthorizeSnapshotAccessRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
      .builder()
      .snapshotIdentifier(snapshotIdentifier: java.lang.String)
      .optionallyWith(
        snapshotClusterIdentifier.map(value => value: java.lang.String)
      )(_.snapshotClusterIdentifier)
      .accountWithRestoreAccess(accountWithRestoreAccess: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly =
    zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.wrap(buildAwsValue())
}
object AuthorizeSnapshotAccessRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.AuthorizeSnapshotAccessRequest =
      zio.aws.redshift.model.AuthorizeSnapshotAccessRequest(
        snapshotIdentifier,
        snapshotClusterIdentifier.map(value => value),
        accountWithRestoreAccess
      )
    def snapshotIdentifier: String
    def snapshotClusterIdentifier: Optional[String]
    def accountWithRestoreAccess: String
    def getSnapshotIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(snapshotIdentifier)
    def getSnapshotClusterIdentifier: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("snapshotClusterIdentifier", snapshotClusterIdentifier)
    def getAccountWithRestoreAccess: ZIO[Any, Nothing, String] =
      ZIO.succeed(accountWithRestoreAccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ) extends zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly {
    override val snapshotIdentifier: String = impl.snapshotIdentifier(): String
    override val snapshotClusterIdentifier: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.snapshotClusterIdentifier())
        .map(value => value: String)
    override val accountWithRestoreAccess: String =
      impl.accountWithRestoreAccess(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ): zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_3-6.20.78.2-sources.jar: zio/aws/redshift/model/AuthorizeSnapshotAccessRequest.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AuthorizeSnapshotAccessRequest(
    snapshotIdentifier: Optional[String] = Optional.Absent,
    snapshotArn: Optional[String] = Optional.Absent,
    snapshotClusterIdentifier: Optional[String] = Optional.Absent,
    accountWithRestoreAccess: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest = {
    import AuthorizeSnapshotAccessRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
      .builder()
      .optionallyWith(snapshotIdentifier.map(value => value: java.lang.String))(
        _.snapshotIdentifier
      )
      .optionallyWith(snapshotArn.map(value => value: java.lang.String))(
        _.snapshotArn
      )
      .optionallyWith(
        snapshotClusterIdentifier.map(value => value: java.lang.String)
      )(_.snapshotClusterIdentifier)
      .accountWithRestoreAccess(accountWithRestoreAccess: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly =
    zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.wrap(buildAwsValue())
}
object AuthorizeSnapshotAccessRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.AuthorizeSnapshotAccessRequest =
      zio.aws.redshift.model.AuthorizeSnapshotAccessRequest(
        snapshotIdentifier.map(value => value),
        snapshotArn.map(value => value),
        snapshotClusterIdentifier.map(value => value),
        accountWithRestoreAccess
      )
    def snapshotIdentifier: Optional[String]
    def snapshotArn: Optional[String]
    def snapshotClusterIdentifier: Optional[String]
    def accountWithRestoreAccess: String
    def getSnapshotIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotIdentifier", snapshotIdentifier)
    def getSnapshotArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotArn", snapshotArn)
    def getSnapshotClusterIdentifier: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("snapshotClusterIdentifier", snapshotClusterIdentifier)
    def getAccountWithRestoreAccess: ZIO[Any, Nothing, String] =
      ZIO.succeed(accountWithRestoreAccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ) extends zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly {
    override val snapshotIdentifier: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotIdentifier())
      .map(value => value: String)
    override val snapshotArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotArn())
      .map(value => value: String)
    override val snapshotClusterIdentifier: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.snapshotClusterIdentifier())
        .map(value => value: String)
    override val accountWithRestoreAccess: String =
      impl.accountWithRestoreAccess(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.AuthorizeSnapshotAccessRequest
  ): zio.aws.redshift.model.AuthorizeSnapshotAccessRequest.ReadOnly =
    new Wrapper(impl)
}
